==> haskell-src-exts-simple-1.23.1.0-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-simple
version:              1.23.1.0
visibility:           public
id:                   haskell-src-exts-simple-1.23.1.0-BIrL370YkHPEWHXquMwbLi
key:                  haskell-src-exts-simple-1.23.1.0-BIrL370YkHPEWHXquMwbLi
license:              MIT
copyright:            2016-2024, Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
homepage:             https://github.com/int-e/haskell-src-exts-simple
synopsis:             A simplified view on the haskell-src-exts AST
description:
    This package provides a shim for haskell-src-exts (HSE), exposing the
    same AST but without annotations, using ghc'\''s pattern synonyms.

    See README.md for further information and compatibility considerations.

category:             Development
abi:                  ce7b24c80d0d483f9ad9328666214fff
exposed:              True
exposed-modules:
    Language.Haskell.Exts.Simple Language.Haskell.Exts.Simple.Build
    Language.Haskell.Exts.Simple.Extension
    Language.Haskell.Exts.Simple.Fixity
    Language.Haskell.Exts.Simple.Parser
    Language.Haskell.Exts.Simple.Pretty
    Language.Haskell.Exts.Simple.Syntax

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-simple
hs-libraries:         HShaskell-src-exts-simple-1.23.1.0-BIrL370YkHPEWHXquMwbLi
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-9n7l75D9wec9NjJsnAfsGi

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-simple/html/haskell-src-exts-simple.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-simple-1.23.1.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-simple
version:              1.23.1.0
visibility:           public
id:                   haskell-src-exts-simple-1.23.1.0-8p0butvPnadAusvd4pXh5N
key:                  haskell-src-exts-simple-1.23.1.0-8p0butvPnadAusvd4pXh5N
license:              MIT
copyright:            2016-2024, Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
homepage:             https://github.com/int-e/haskell-src-exts-simple
synopsis:             A simplified view on the haskell-src-exts AST
description:
    This package provides a shim for haskell-src-exts (HSE), exposing the
    same AST but without annotations, using ghc'\''s pattern synonyms.

    See README.md for further information and compatibility considerations.

category:             Development
abi:                  9aabe699d5e5ef9fa7390eaae3b8c05d
exposed:              True
exposed-modules:
    Language.Haskell.Exts.Simple Language.Haskell.Exts.Simple.Build
    Language.Haskell.Exts.Simple.Extension
    Language.Haskell.Exts.Simple.Fixity
    Language.Haskell.Exts.Simple.Parser
    Language.Haskell.Exts.Simple.Pretty
    Language.Haskell.Exts.Simple.Syntax

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-simple
hs-libraries:         HShaskell-src-exts-simple-1.23.1.0-8p0butvPnadAusvd4pXh5N
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-3zeFV5yyIoCHUr81tDp8Dm

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-simple/html/haskell-src-exts-simple.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
